/* v0.9
 *
 * shields.h:  Shields module header.
 *
 * This program is free software and may be freely redistributed as
 * specified in the GNU General Public License.  Please see the file
 * 'COPYING' for details.   
 */

extern void shdAllocCheck(TAG *);
extern void shdAllocate(TAG *, dbref, int*);
extern void shdMaintainShields(TAG *);
extern void shdCloakOn(TAG *, dbref);
extern void shdCloakOff(TAG *, dbref);
extern void shdRaiseShield(TAG *, dbref, int);
extern void shdLowerShield(TAG *, dbref, int);
extern const char *shdFullName(const TAG *, int);
extern const char *shdShortName(const TAG *, int);
extern const char *shdCharName(const TAG *, int);
extern const char *shdConfigName(const TAG *);
